@@ -34,37 +34,42 @@ QLatin1String AgentType::CapabilityAutostart = QLatin1String( AKONADI_AGENT_CAPA
 QLatin1String AgentType::CapabilityPreprocessor = QLatin1String( AKONADI_AGENT_CAPABILITY_PREPROCESSOR );
 QLatin1String AgentType::CapabilitySearch = QLatin1String( AKONADI_AGENT_CAPABILITY_SEARCH );
 
-AgentType::AgentType() :
-    instanceCounter( 0 )
+AgentType::AgentType()
+  : instanceCounter( 0 )
 {
 }
 
-bool AgentType::load(const QString & fileName, AgentManager * manager)
+bool AgentType::load( const QString &fileName, AgentManager *manager )
 {
-  QSettings file( fileName, QSettings::IniFormat );
-  file.beginGroup( QLatin1String("Desktop Entry") );
+  Q_UNUSED( manager );
 
-  Q_FOREACH(const QString& key, file.allKeys() ) {
-    if ( key.startsWith( QLatin1String("Name[") ) ) {
-      QString lang = key.mid( 5, key.length()-6);
+  QSettings file( fileName, QSettings::IniFormat );
+  file.beginGroup( QLatin1String( "Desktop Entry" ) );
+
+  Q_FOREACH ( const QString &key, file.allKeys() ) {
+    if ( key.startsWith( QLatin1String( "Name[" ) ) ) {
+      QString lang = key.mid( 5, key.length() - 6 );
       name.insert( lang, QString::fromUtf8( file.value( key ).toByteArray() ) );
-    } else if ( key == QLatin1String("Name") ) {
-      name.insert( QLatin1String("en_US"), QString::fromUtf8( file.value( QLatin1String("Name") ).toByteArray() ) );
-    } else if ( key.startsWith( QLatin1String("Comment[") ) ) {
-      QString lang = key.mid( 8, key.length()-9);
-      comment.insert( lang, QString::fromUtf8( file.value( key ).toByteArray() )  );
-    } else if ( key == QLatin1String("Comment") ) {
-      comment.insert( QLatin1String("en_US"), QString::fromUtf8( file.value( QLatin1String("Comment") ).toByteArray() ) );
+    } else if ( key == QLatin1String( "Name" ) ) {
+      name.insert( QLatin1String( "en_US" ), QString::fromUtf8( file.value( QLatin1String( "Name" ) ).toByteArray() ) );
+    } else if ( key.startsWith( QLatin1String( "Comment[" ) ) ) {
+      QString lang = key.mid( 8, key.length() - 9 );
+      comment.insert( lang, QString::fromUtf8( file.value( key ).toByteArray() ) );
+    } else if ( key == QLatin1String( "Comment" ) ) {
+      comment.insert( QLatin1String( "en_US" ), QString::fromUtf8( file.value( QLatin1String( "Comment" ) ).toByteArray() ) );
+    } else if ( key.startsWith( QLatin1String( "X-Akonadi-Custom-" ) ) ) {
+      QString customKey = key.mid( 17, key.length() );
+      custom[customKey] = file.value( key );
     }
   }
-  icon = file.value( QLatin1String("Icon") ).toString();
-  mimeTypes = file.value( QLatin1String("X-Akonadi-MimeTypes") ).toStringList();
-  capabilities = file.value( QLatin1String("X-Akonadi-Capabilities") ).toStringList();
-  exec = file.value( QLatin1String("Exec") ).toString();
-  identifier = file.value( QLatin1String("X-Akonadi-Identifier") ).toString();
+  icon = file.value( QLatin1String( "Icon" ) ).toString();
+  mimeTypes = file.value( QLatin1String( "X-Akonadi-MimeTypes" ) ).toStringList();
+  capabilities = file.value( QLatin1String( "X-Akonadi-Capabilities" ) ).toStringList();
+  exec = file.value( QLatin1String( "Exec" ) ).toString();
+  identifier = file.value( QLatin1String( "X-Akonadi-Identifier" ) ).toString();
   launchMethod = Process; // Save default
 
-  const QString method = file.value( QLatin1String("X-Akonadi-LaunchMethod") ).toString();
+  const QString method = file.value( QLatin1String( "X-Akonadi-LaunchMethod" ) ).toString();
   if ( method.compare( QLatin1String( "AgentProcess" ), Qt::CaseInsensitive ) == 0 ) {
     launchMethod = Process;
   } else if ( method.compare( QLatin1String( "AgentServer" ), Qt::CaseInsensitive ) == 0 ) {
@@ -87,8 +92,9 @@ bool AgentType::load(const QString & fileName, AgentManager * manager)
   }
 
   // autostart implies unique
-  if ( capabilities.contains( CapabilityAutostart ) && !capabilities.contains( CapabilityUnique ) )
+  if ( capabilities.contains( CapabilityAutostart ) && !capabilities.contains( CapabilityUnique ) ) {
     capabilities << CapabilityUnique;
+  }
 
   // load instance count if needed
   if ( !capabilities.contains( CapabilityUnique ) ) {
