@@ -33,6 +33,8 @@
 #include "storage/entity.h"
 #include "storage/transaction.h"
 
+#include <libs/protocol_p.h>
+
 #include <QtCore/QDebug>
 
 using namespace Akonadi;
@@ -54,36 +56,46 @@ bool Akonadi::AkAppend::commit()
     Transaction transaction( db );
 
     Collection col = HandlerHelper::collectionFromIdOrName( m_mailbox );
-    if ( !col.isValid() )
+    if ( !col.isValid() ) {
       return failureResponse( QByteArray( "Unknown collection for '" ) + m_mailbox + QByteArray( "'." ) );
+    }
 
     QByteArray mt;
     QString remote_id;
     QString remote_revision;
+    QString gid;
     QList<QByteArray> flags;
-    Q_FOREACH( const QByteArray &flag, m_flags ) {
-      if ( flag.startsWith( "\\MimeType" ) ) {
+    Q_FOREACH ( const QByteArray &flag, m_flags ) {
+      if ( flag.startsWith( AKONADI_FLAG_MIMETYPE ) ) {
         int pos1 = flag.indexOf( '[' );
         int pos2 = flag.indexOf( ']', pos1 );
         mt = flag.mid( pos1 + 1, pos2 - pos1 - 1 );
-      } else if ( flag.startsWith( "\\RemoteId" ) ) {
+      } else if ( flag.startsWith( AKONADI_FLAG_REMOTEID ) ) {
         int pos1 = flag.indexOf( '[' );
         int pos2 = flag.lastIndexOf( ']' );
         remote_id = QString::fromUtf8( flag.mid( pos1 + 1, pos2 - pos1 - 1 ) );
-      } else if ( flag.startsWith( "\\RemoteRevision" ) ) {
+      } else if ( flag.startsWith( AKONADI_FLAG_REMOTEREVISION ) ) {
         int pos1 = flag.indexOf( '[' );
         int pos2 = flag.lastIndexOf( ']' );
         remote_revision = QString::fromUtf8( flag.mid( pos1 + 1, pos2 - pos1 - 1 ) );
-      } else
+      } else if ( flag.startsWith( AKONADI_FLAG_GID ) ) {
+        int pos1 = flag.indexOf( '[' );
+        int pos2 = flag.lastIndexOf( ']' );
+        gid = QString::fromUtf8( flag.mid( pos1 + 1, pos2 - pos1 - 1 ) );
+      } else {
         flags << flag;
+      }
     }
     // standard imap does not know this attribute, so that's mail
-    if ( mt.isEmpty() ) mt = "message/rfc822";
+    if ( mt.isEmpty() ) {
+      mt = "message/rfc822";
+    }
     MimeType mimeType = MimeType::retrieveByName( QString::fromLatin1( mt ) );
     if ( !mimeType.isValid() ) {
       MimeType m( QString::fromLatin1( mt ) );
-      if ( !m.insert() )
-        return failureResponse( QByteArray( "Unable to create mimetype '") + mt + QByteArray( "'." ) );
+      if ( !m.insert() ) {
+        return failureResponse( QByteArray( "Unable to create mimetype '" ) + mt + QByteArray( "'." ) );
+      }
       mimeType = m;
     }
 
@@ -91,43 +103,42 @@ bool Akonadi::AkAppend::commit()
     item.setRev( 0 );
     item.setSize( m_size );
 
-
     // If we have active preprocessors then we also set the hidden attribute
     // for the UI and we enqueue the item for preprocessing.
     bool doPreprocessing = PreprocessorManager::instance()->isActive();
 
-    if ( doPreprocessing )
-    {
+    if ( doPreprocessing ) {
       Part hiddenAttribute;
-      hiddenAttribute.setName( QLatin1String( "ATR:HIDDEN" ) );
+      hiddenAttribute.setName( QLatin1String( AKONADI_ATTRIBUTE_HIDDEN ) );
       hiddenAttribute.setData( QByteArray() );
       hiddenAttribute.setPimItemId( item.id() );
 
       m_parts.append( hiddenAttribute );
     }
 
-    bool ok = db->appendPimItem( m_parts, mimeType, col, m_dateTime, remote_id, remote_revision, item );
+    bool ok = db->appendPimItem( m_parts, mimeType, col, m_dateTime, remote_id, remote_revision, gid, item );
 
     response.setTag( tag() );
     if ( !ok ) {
-        return failureResponse( "Append failed" );
+      return failureResponse( "Append failed" );
     }
 
     // set message flags
     const Flag::List flagList = HandlerHelper::resolveFlags( flags );
     bool flagsChanged = false;
-    if ( !db->appendItemsFlags( PimItem::List() << item, flagList, flagsChanged, false, col ) )
+    if ( !db->appendItemsFlags( PimItem::List() << item, flagList, flagsChanged, false, col ) ) {
       return failureResponse( "Unable to append item flags." );
+    }
 
     // TODO if the mailbox is currently selected, the normal new message
     //      actions SHOULD occur.  Specifically, the server SHOULD notify the
     //      client immediately via an untagged EXISTS response.
 
-    if ( !transaction.commit() )
-        return failureResponse( "Unable to commit transaction." );
+    if ( !transaction.commit() ) {
+      return failureResponse( "Unable to commit transaction." );
+    }
 
-    if ( doPreprocessing )
-    {
+    if ( doPreprocessing ) {
       // enqueue the item for preprocessing
       PreprocessorManager::instance()->beginHandleItem( item, db );
     }
@@ -185,19 +196,17 @@ bool AkAppend::parseStream()
   bool ok = false;
 
   QList<QByteArray> list = m_streamParser->readParenthesizedList();
-  Q_FOREACH( const QByteArray &item, list )
-  {
-    if (partName.isEmpty() && partSize == -1)
-    {
+  Q_FOREACH ( const QByteArray &item, list ) {
+    if ( partName.isEmpty() && partSize == -1 ) {
       partName = item;
       continue;
     }
-    if (item.startsWith(':'))
-    {
+    if ( item.startsWith( ':' ) ) {
       int pos = 1;
       ImapParser::parseNumber( item, partSize, &ok, pos );
-      if( !ok )
+      if ( !ok ) {
         partSize = 0;
+      }
 
       int version = 0;
       QByteArray plainPartName;
@@ -218,13 +227,14 @@ bool AkAppend::parseStream()
   // chop up literal data in parts
   int pos = 0; // traverse through part data now
   QPair<QByteArray, QPair<qint64, int> > partSpec;
-  Q_FOREACH( partSpec, partSpecs ) {
+  Q_FOREACH ( partSpec, partSpecs ) {
     // wrap data into a part
     Part part;
     part.setName( QLatin1String( partSpec.first ) );
     part.setData( allParts.mid( pos, partSpec.second.first ) );
-    if ( partSpec.second.second != 0 )
+    if ( partSpec.second.second != 0 ) {
       part.setVersion( partSpec.second.second );
+    }
     part.setDatasize( partSpec.second.first );
     m_parts.append( part );
     pos += partSpec.second.first;
@@ -232,4 +242,3 @@ bool AkAppend::parseStream()
 
   return commit();
 }
-
