@@ -36,7 +36,8 @@
 
 using namespace Akonadi;
 
-Modify::Modify( Scope::SelectionScope scope ) : m_scope( scope )
+Modify::Modify( Scope::SelectionScope scope )
+  : m_scope( scope )
 {
 }
 
@@ -45,32 +46,33 @@ bool Modify::parseStream()
   m_scope.parseScope( m_streamParser );
   SelectQueryBuilder<Collection> qb;
   CollectionQueryHelper::scopeToQuery( m_scope, connection(), qb );
-  if ( !qb.exec() )
+  if ( !qb.exec() ) {
     throw HandlerException( "Unable to execute collection query" );
+  }
   const Collection::List collections = qb.result();
-  if ( collections.isEmpty() )
+  if ( collections.isEmpty() ) {
     throw HandlerException( "No such collection" );
-  if ( collections.size() > 1 ) // TODO
+  }
+  if ( collections.size() > 1 ) { // TODO
     throw HandlerException( "Mass-modifying collections is not yet implemented" );
+  }
   Collection collection = collections.first();
 
-
   //TODO: do it cleanly with the streaming parser, which doesn't have look-ahead at this moment
   QByteArray line = m_streamParser->readUntilCommandEnd();
   m_streamParser->insertData( "\n" );
 
   int p = 0;
-  if ( (p = line.indexOf( "PARENT ")) > 0 ) {
+  if ( ( p = line.indexOf( AKONADI_PARAM_PARENT ) ) > 0 ) {
     QByteArray tmp;
     ImapParser::parseString( line, tmp, p + 6 );
     const Collection newParent = HandlerHelper::collectionFromIdOrName( tmp );
     if ( newParent.isValid() && collection.parentId() != newParent.id()
-         && collection.resourceId() != newParent.resourceId() )
-    {
+         && collection.resourceId() != newParent.resourceId() ) {
       ItemRetriever retriever( connection() );
       retriever.setCollection( collection, true );
       retriever.setRetrieveFullPayload( true );
-      if (!retriever.exec()) {
+      if ( !retriever.exec()  ) {
         throw HandlerException( retriever.lastError() );
       }
     }
@@ -88,8 +90,9 @@ bool Modify::parseStream()
       QList<QByteArray> mimeTypes;
       pos = ImapParser::parseParenthesizedList( line, mimeTypes, pos );
       QStringList mts;
-      Q_FOREACH ( const QByteArray &ba, mimeTypes )
-        mts << QString::fromLatin1(ba);
+      Q_FOREACH ( const QByteArray &ba, mimeTypes ) {
+        mts << QString::fromLatin1( ba );
+      }
       MimeType::List currentMts = collection.mimeTypes();
       bool equal = true;
       Q_FOREACH ( const MimeType &currentMt, currentMts ) {
@@ -98,57 +101,70 @@ bool Modify::parseStream()
           continue;
         }
         equal = false;
-        if ( !collection.removeMimeType( currentMt ) )
+        if ( !collection.removeMimeType( currentMt ) ) {
           throw HandlerException( "Unable to remove collection mimetype" );
+        }
       }
-      if ( !db->appendMimeTypeForCollection( collection.id(), mts ) )
+      if ( !db->appendMimeTypeForCollection( collection.id(), mts ) ) {
         return failureResponse( "Unable to add collection mimetypes" );
-      if ( !equal || !mts.isEmpty() )
+      }
+      if ( !equal || !mts.isEmpty() ) {
         changes.append( AKONADI_PARAM_MIMETYPE );
+      }
     } else if ( type == AKONADI_PARAM_CACHEPOLICY ) {
       bool changed = false;
       pos = HandlerHelper::parseCachePolicy( line, collection, pos, &changed );
-      if ( changed )
+      if ( changed ) {
         changes.append( AKONADI_PARAM_CACHEPOLICY );
+      }
     } else if ( type == AKONADI_PARAM_NAME ) {
       QString newName;
       pos = ImapParser::parseString( line, newName, pos );
-      if ( collection.name() == newName )
+      if ( collection.name() == newName ) {
         continue;
-      if ( !CollectionQueryHelper::hasAllowedName( collection, newName, collection.parentId() ) )
+      }
+      if ( !CollectionQueryHelper::hasAllowedName( collection, newName, collection.parentId() ) ) {
         throw HandlerException( "Collection with the same name exists already" );
+      }
       collection.setName( newName );
       changes.append( AKONADI_PARAM_NAME );
-    } else if ( type == "PARENT" ) {
+    } else if ( type == AKONADI_PARAM_PARENT ) {
       qint64 newParent;
       bool ok = false;
       pos = ImapParser::parseNumber( line, newParent, &ok, pos );
-      if ( !ok )
+      if ( !ok ) {
         return failureResponse( "Invalid syntax" );
-      if ( collection.parentId() == newParent )
+      }
+      if ( collection.parentId() == newParent ) {
         continue;
-      if ( !db->moveCollection( collection, Collection::retrieveById( newParent ) ) )
+      }
+      if ( !db->moveCollection( collection, Collection::retrieveById( newParent ) ) ) {
         return failureResponse( "Unable to reparent collection" );
-      changes.append( "PARENT" );
-    } else if ( type == "VIRTUAL" ) {
+      }
+      changes.append( AKONADI_PARAM_PARENT );
+    } else if ( type == AKONADI_PARAM_VIRTUAL ) {
       QString newValue;
       pos = ImapParser::parseString( line, newValue, pos );
-      if ( newValue.toInt() != collection.isVirtual() )
+      if ( newValue.toInt() != collection.isVirtual() ) {
           return failureResponse( "Can't modify VIRTUAL collection flag" );
+      }
     } else if ( type == AKONADI_PARAM_REMOTEID ) {
       QString rid;
       pos = ImapParser::parseString( line, rid, pos );
-      if ( rid == collection.remoteId() )
+      if ( rid == collection.remoteId() ) {
         continue;
-      if ( !connection()->isOwnerResource( collection ) )
+      }
+      if ( !connection()->isOwnerResource( collection ) ) {
         throw HandlerException( "Only resources can modify remote identifiers" );
+      }
       collection.setRemoteId( rid );
       changes.append( AKONADI_PARAM_REMOTEID );
     } else if ( type == AKONADI_PARAM_REMOTEREVISION ) {
       QString remoteRevision;
       pos = ImapParser::parseString( line, remoteRevision, pos );
-      if ( remoteRevision == collection.remoteRevision() )
+      if ( remoteRevision == collection.remoteRevision() ) {
         continue;
+      }
       collection.setRemoteRevision( remoteRevision );
       changes.append( AKONADI_PARAM_REMOTEREVISION );
     } else if ( type == AKONADI_PARAM_PERSISTENTSEARCH ) {
@@ -160,10 +176,11 @@ bool Modify::parseStream()
       for ( int i = 0; i < queryArgs.size() - 1; i += 2 ) {
         const QByteArray key = queryArgs.at( i );
         const QByteArray value = queryArgs.at( i + 1 );
-        if ( key == AKONADI_PARAM_PERSISTENTSEARCH_QUERYLANG )
+        if ( key == AKONADI_PARAM_PERSISTENTSEARCH_QUERYLANG ) {
           queryLang = QString::fromLatin1( value );
-        else if ( key == AKONADI_PARAM_PERSISTENTSEARCH_QUERYSTRING )
+        } else if ( key == AKONADI_PARAM_PERSISTENTSEARCH_QUERYSTRING ) {
           queryString = QString::fromUtf8( value );
+        }
       }
       if ( collection.queryLanguage() != queryLang || collection.queryString() != queryString ) {
         collection.setQueryLanguage( queryLang );
@@ -179,8 +196,9 @@ bool Modify::parseStream()
       // custom attribute
       if ( type.startsWith( '-' ) ) {
         type = type.mid( 1 );
-        if ( db->removeCollectionAttribute( collection, type ) )
+        if ( db->removeCollectionAttribute( collection, type ) ) {
           changes.append( type );
+        }
       } else {
         QByteArray value;
         pos = ImapParser::parseString( line, value, pos );
@@ -188,8 +206,9 @@ bool Modify::parseStream()
         SelectQueryBuilder<CollectionAttribute> qb;
           qb.addValueCondition( CollectionAttribute::collectionIdColumn(), Query::Equals, collection.id() );
         qb.addValueCondition( CollectionAttribute::typeColumn(), Query::Equals, type );
-        if ( !qb.exec() )
+        if ( !qb.exec() ) {
           throw HandlerException( "Unable to retrieve collection attribute" );
+        }
 
         const CollectionAttribute::List attrs = qb.result();
         if ( attrs.isEmpty() ) {
@@ -197,16 +216,19 @@ bool Modify::parseStream()
           attr.setCollectionId( collection.id() );
           attr.setType( type );
           attr.setValue( value );
-          if ( !attr.insert() )
+          if ( !attr.insert() ) {
             throw HandlerException( "Unable to add collection attribute" );
+          }
           changes.append( type );
         } else if ( attrs.size() == 1 ) {
           CollectionAttribute attr = attrs.first();
-          if ( attr.value() == value )
+          if ( attr.value() == value ) {
             continue;
+          }
           attr.setValue( value );
-          if ( !attr.update() )
+          if ( !attr.update() ) {
             throw HandlerException( "Unable to update collection attribute" );
+          }
           changes.append( type );
         } else {
           throw HandlerException( "WTF: more than one attribute with the same name" );
@@ -216,11 +238,13 @@ bool Modify::parseStream()
   }
 
   if ( !changes.isEmpty() ) {
-    if ( collection.hasPendingChanges() && !collection.update() )
+    if ( collection.hasPendingChanges() && !collection.update() ) {
       return failureResponse( "Unable to update collection" );
+    }
     db->notificationCollector()->collectionChanged( collection, changes );
-    if ( !transaction.commit() )
+    if ( !transaction.commit() ) {
       return failureResponse( "Unable to commit transaction" );
+    }
   }
 
   Response response;
@@ -229,4 +253,3 @@ bool Modify::parseStream()
   Q_EMIT responseAvailable( response );
   return true;
 }
-
