@@ -17,7 +17,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-
 #include "akonadi.h"
 #include "akapplication.h"
 #include "akdbus.h"
@@ -36,7 +35,7 @@
 #ifdef QT_STATICPLUGIN
 #include <QtPlugin>
 
-Q_IMPORT_PLUGIN(qsqlite3)
+Q_IMPORT_PLUGIN( qsqlite3 )
 #endif
 
 #ifndef _WIN32_WCE
@@ -54,11 +53,7 @@ void shutdownHandler( int )
 
 int main( int argc, char ** argv )
 {
-#ifndef _WIN32_WCE
     Q_INIT_RESOURCE( akonadidb );
-#else
-    Q_INIT_RESOURCE( akonadidb_mobile );
-#endif
     AkCoreApplication app( argc, argv );
     app.setDescription( QLatin1String( "Akonadi Server\nDo not run manually, use 'akonadictl' instead to start/stop Akonadi." ) );
 
@@ -79,7 +74,7 @@ int main( int argc, char ** argv )
 #else
    if (
 #endif
-        !QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::ControlLock) ) ) {
+        !QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName( AkDBus::ControlLock ) ) ) {
      akError() << "Akonadi control process not found - aborting.";
      akFatal() << "If you started akonadiserver manually, try 'akonadictl start' instead.";
    }
@@ -91,11 +86,7 @@ int main( int argc, char ** argv )
 
     Akonadi::AkonadiServer::instance()->quit();
 
-#ifndef _WIN32_WCE
     Q_CLEANUP_RESOURCE( akonadidb );
-#else
-    Q_CLEANUP_RESOURCE( akonadidb_mobile );
-#endif
 
     return result;
 }
