@@ -29,8 +29,8 @@ using namespace Akonadi;
 
 static qint64 resultToId( const Nepomuk::Query::Result &result )
 {
-  const Soprano::Node &property = result.requestProperty(QUrl( QLatin1String( "http://akonadi-project.org/ontologies/aneo#akonadiItemId" ) ));
-  if (!(property.isValid() && property.isLiteral() && property.literal().isString())) {
+  const Soprano::Node &property = result.requestProperty( QUrl( QLatin1String( "http://akonadi-project.org/ontologies/aneo#akonadiItemId" ) ) );
+  if ( !( property.isValid() && property.isLiteral() && property.literal().isString() ) ) {
     qWarning() << "Failed to get requested akonadiItemId property";
     qDebug() << "AkonadiItemId missing in query results!" << result.resourceUri() << property.isValid() << property.isLiteral() << property.literal().isString() << property.literal().type() << result.requestProperties().size();
 //    qDebug() << result.requestProperties().values().first().toString();
@@ -39,8 +39,9 @@ static qint64 resultToId( const Nepomuk::Query::Result &result )
   return property.literal().toString().toLongLong();
 }
 
-NepomukSearch::NepomukSearch( QObject* parent )
-  : QObject( parent ), mSearchService( 0 )
+NepomukSearch::NepomukSearch( QObject *parent )
+  : QObject( parent )
+  , mSearchService( 0 )
 {
   mSearchService = new Nepomuk::Query::QueryServiceClient( this );
   connect( mSearchService, SIGNAL(newEntries(QList<Nepomuk::Query::Result>)),
@@ -65,7 +66,7 @@ QStringList NepomukSearch::search( const QString &query )
   // be part of the query already and extracted from that,
   // but that doesn't seem to work at the moment, so be explicit.
   QHash<QString, QString> encodedRps;
-  encodedRps.insert( QString::fromLatin1( "reqProp1" ), QUrl(QString::fromLatin1("http://akonadi-project.org/ontologies/aneo#akonadiItemId")).toString() );
+  encodedRps.insert( QString::fromLatin1( "reqProp1" ), QUrl( QString::fromLatin1( "http://akonadi-project.org/ontologies/aneo#akonadiItemId" ) ).toString() );
 
   if ( !mSearchService->blockingQuery( query, encodedRps ) ) {
     qWarning() << Q_FUNC_INFO << "Calling blockingQuery() failed!" << query;
@@ -81,13 +82,13 @@ QStringList NepomukSearch::search( const QString &query )
             this, SLOT(idHitsAdded(QList<Nepomuk::Query::Result>)) );
 
     // go fetch the akonadi item id property for those results that don't have them
-    Q_FOREACH( const Nepomuk::Query::Result &result, mResultsWithoutIdProperty ) {
+    Q_FOREACH ( const Nepomuk::Query::Result &result, mResultsWithoutIdProperty ) {
       qDebug() << "NepomukSearch::hitsAdded() search for IDs for results without ids: " << result.resourceUri().toString();
       QHash<QString, QString> encodedRps;
       // We do another query to get the akonadiItemId attribute (since it may not have been added to the original query)
-      encodedRps.insert( QString::fromLatin1( "reqProp1" ), QUrl(QString::fromLatin1("http://akonadi-project.org/ontologies/aneo#akonadiItemId")).toString() );
+      encodedRps.insert( QString::fromLatin1( "reqProp1" ), QUrl( QString::fromLatin1( "http://akonadi-project.org/ontologies/aneo#akonadiItemId" ) ).toString() );
 
-      idSearchService.blockingQuery(QString::fromLatin1("SELECT DISTINCT ?r ?reqProp1 WHERE { <%1> a ?v2 . <%1> <http://akonadi-project.org/ontologies/aneo#akonadiItemId> ?reqProp1 . } LIMIT 1").arg(result.resourceUri().toString()), encodedRps);
+      idSearchService.blockingQuery( QString::fromLatin1( "SELECT DISTINCT ?r ?reqProp1 WHERE { <%1> a ?v2 . <%1> <http://akonadi-project.org/ontologies/aneo#akonadiItemId> ?reqProp1 . } LIMIT 1" ).arg( result.resourceUri().toString() ), encodedRps );
     }
     mResultsWithoutIdProperty.clear();
   }
@@ -95,39 +96,39 @@ QStringList NepomukSearch::search( const QString &query )
   return mMatchingUIDs.toList();
 }
 
-void NepomukSearch::addHit(const Nepomuk::Query::Result& result)
+void NepomukSearch::addHit( const Nepomuk::Query::Result &result )
 {
   const qint64 itemId = resultToId( result );
 
-  if ( itemId == -1 )
+  if ( itemId == -1 ) {
     return;
+  }
 
   mMatchingUIDs.insert( QString::number( itemId ) );
 }
 
-void NepomukSearch::hitsAdded( const QList<Nepomuk::Query::Result>& entries )
+void NepomukSearch::hitsAdded( const QList<Nepomuk::Query::Result> &entries )
 {
   if ( !mSearchService->serviceAvailable() ) {
     qWarning() << "Nepomuk search service not available!";
     return;
   }
 
-  Q_FOREACH( const Nepomuk::Query::Result &result, entries ) {
-    const Soprano::Node &property = result.requestProperty(QUrl( QLatin1String( "http://akonadi-project.org/ontologies/aneo#akonadiItemId" ) ));
-    if (!(property.isValid() && property.isLiteral() && property.literal().isString())) {
+  Q_FOREACH ( const Nepomuk::Query::Result &result, entries ) {
+    const Soprano::Node &property = result.requestProperty( QUrl( QLatin1String( "http://akonadi-project.org/ontologies/aneo#akonadiItemId" ) ) );
+    if ( !( property.isValid() && property.isLiteral() && property.literal().isString() ) ) {
       mResultsWithoutIdProperty << result;
     } else {
       // for those results that already have a proper akonadi item id property,
       // we can add matches right away
-      addHit(result);
+      addHit( result );
     }
   }
 }
 
-void NepomukSearch::idHitsAdded(const QList< Nepomuk::Query::Result >& entries)
+void NepomukSearch::idHitsAdded( const QList< Nepomuk::Query::Result > &entries )
 {
-  Q_FOREACH( const Nepomuk::Query::Result &result, entries ) {
-    addHit(result);
+  Q_FOREACH ( const Nepomuk::Query::Result &result, entries ) {
+    addHit( result );
   }
 }
-
