@@ -33,10 +33,9 @@
 #include <QDBusConnection>
 #include <QSettings>
 
-
 using namespace Akonadi;
 
-NotificationManager* NotificationManager::mSelf = 0;
+NotificationManager *NotificationManager::mSelf = 0;
 
 NotificationManager::NotificationManager()
   : QObject( 0 )
@@ -45,15 +44,15 @@ NotificationManager::NotificationManager()
   NotificationMessageV2::registerDBusTypes();
 
   new NotificationManagerAdaptor( this );
-  QDBusConnection::sessionBus().registerObject( QLatin1String("/notifications"),
+  QDBusConnection::sessionBus().registerObject( QLatin1String( "/notifications" ),
     this, QDBusConnection::ExportAdaptors );
-  QDBusConnection::sessionBus().registerObject( QLatin1String("/notifications/debug"),
+  QDBusConnection::sessionBus().registerObject( QLatin1String( "/notifications/debug" ),
     this, QDBusConnection::ExportScriptableSlots );
 
   const QString serverConfigFile = AkStandardDirs::serverConfigFile( XdgBaseDirs::ReadWrite );
   QSettings settings( serverConfigFile, QSettings::IniFormat );
 
-  mTimer.setInterval( settings.value( QLatin1String("NotificationManager/Interval"), 50 ).toInt() );
+  mTimer.setInterval( settings.value( QLatin1String( "NotificationManager/Interval" ), 50 ).toInt() );
   mTimer.setSingleShot( true );
   connect( &mTimer, SIGNAL(timeout()), SLOT(emitPendingNotifications()) );
 }
@@ -62,35 +61,38 @@ NotificationManager::~NotificationManager()
 {
 }
 
-NotificationManager* NotificationManager::self()
+NotificationManager *NotificationManager::self()
 {
-  if ( !mSelf )
+  if ( !mSelf ) {
     mSelf = new NotificationManager();
+  }
 
   return mSelf;
 }
 
-void NotificationManager::connectNotificationCollector(NotificationCollector* collector)
+void NotificationManager::connectNotificationCollector( NotificationCollector *collector )
 {
   connect( collector, SIGNAL(notify(Akonadi::NotificationMessageV2::List)),
            SLOT(slotNotify(Akonadi::NotificationMessageV2::List)) );
 }
 
-void NotificationManager::slotNotify(const Akonadi::NotificationMessageV2::List &msgs)
+void NotificationManager::slotNotify( const Akonadi::NotificationMessageV2::List &msgs )
 {
   //akDebug() << Q_FUNC_INFO << "Appending" << msgs.count() << "notifications to current list of " << mNotifications.count() << "notifications";
   Q_FOREACH ( const NotificationMessageV2 &msg, msgs )
     NotificationMessageV2::appendAndCompress( mNotifications, msg );
   //akDebug() << Q_FUNC_INFO << "We have" << mNotifications.count() << "notifications queued in total after appendAndCompress()";
 
-  if ( !mTimer.isActive() )
+  if ( !mTimer.isActive() ) {
     mTimer.start();
+  }
 }
 
 void NotificationManager::emitPendingNotifications()
 {
-  if ( mNotifications.isEmpty() )
+  if ( mNotifications.isEmpty() ) {
     return;
+  }
 
   NotificationMessage::List legacyNotifications;
   Q_FOREACH ( const NotificationMessageV2 &notification, mNotifications ) {
@@ -108,46 +110,95 @@ void NotificationManager::emitPendingNotifications()
     }
   }
 
-  Q_FOREACH( NotificationSource *src, mNotificationSources ) {
-    if ( !legacyNotifications.isEmpty() ) {
+  if ( !legacyNotifications.isEmpty() ) {
+    Q_FOREACH ( NotificationSource *src, mNotificationSources ) {
       src->emitNotification( legacyNotifications );
     }
-    if ( ClientCapabilityAggregator::maximumNotificationMessageVersion() > 1 ) {
-      src->emitNotification( mNotifications );
+  }
+
+  if ( ClientCapabilityAggregator::maximumNotificationMessageVersion() > 1 ) {
+    Q_FOREACH ( NotificationSource *source, mNotificationSources ) {
+      if ( !source->isServerSideMonitorEnabled() ) {
+        source->emitNotification( mNotifications );
+        continue;
+      }
+
+      NotificationMessageV2::List acceptedNotifications;
+      Q_FOREACH ( const NotificationMessageV2 &notification, mNotifications ) {
+        if ( source->acceptsNotification( notification ) ) {
+          acceptedNotifications << notification;
+        }
+      }
+
+      if ( !acceptedNotifications.isEmpty() ) {
+        source->emitNotification( acceptedNotifications );
+      }
     }
   }
 
   // backward compatibility with the old non-subcription interface
-  if ( !legacyNotifications.isEmpty() )
+  // FIXME: Can we drop this already?
+  if ( !legacyNotifications.isEmpty() ) {
     Q_EMIT notify( legacyNotifications );
+  }
 
   mNotifications.clear();
 }
 
-
-
-QDBusObjectPath NotificationManager::subscribe( const QString &identifier )
+QDBusObjectPath NotificationManager::subscribeV2( const QString &identifier, bool serverSideMonitor )
 {
+  akDebug() << Q_FUNC_INFO << this << identifier << serverSideMonitor;
+
   NotificationSource *source = mNotificationSources.value( identifier );
   if ( source ) {
     akDebug() << "Known subscriber" << identifier << "subscribes again";
     source->addClientServiceName( message().service() );
   } else {
     source = new NotificationSource( identifier, message().service(), this );
-    mNotificationSources.insert( identifier, source );
   }
+
+  registerSource( source );
+  source->setServerSideMonitorEnabled( serverSideMonitor );
+
+  Q_EMIT subscribed( identifier );
+
   return source->dbusPath();
 }
 
+void NotificationManager::registerSource( NotificationSource *source )
+{
+  mNotificationSources.insert( source->identifier(), source );
+}
 
+QDBusObjectPath NotificationManager::subscribe( const QString &identifier )
+{
+  akDebug() << Q_FUNC_INFO << this << identifier;
+  return subscribeV2( identifier, false );
+}
 
 void NotificationManager::unsubscribe( const QString &identifier )
 {
-  NotificationSource *source = mNotificationSources.take( identifier );
+  NotificationSource *source = mNotificationSources.value( identifier );
   if ( source ) {
+    unregisterSource( source );
     source->deleteLater();
+    Q_EMIT unsubscribed( identifier );
   } else {
     akDebug() << "Attempt to unsubscribe unknown subscriber" << identifier;
   }
 }
 
+void NotificationManager::unregisterSource( NotificationSource *source )
+{
+  mNotificationSources.remove( source->identifier() );
+}
+
+QStringList NotificationManager::subscribers() const
+{
+  QStringList identifiers;
+  Q_FOREACH ( NotificationSource *source, mNotificationSources ) {
+    identifiers << source->identifier();
+  }
+
+  return identifiers;
+}
