@@ -22,12 +22,15 @@
 
 #include "../libs/notificationmessage_p.h"
 #include "../libs/notificationmessagev2_p.h"
+#include "storage/entity.h"
 
 #include <QtCore/QHash>
 #include <QtCore/QObject>
 #include <QtCore/QTimer>
 #include <QtDBus/qdbuscontext.h>
 
+class NotificationManagerTest;
+
 namespace Akonadi {
 
 class NotificationCollector;
@@ -59,6 +62,15 @@ class NotificationManager : public QObject, protected QDBusContext
      */
     Q_SCRIPTABLE QDBusObjectPath subscribe( const QString &identifier );
 
+    /**
+     * Subscribe to notifications emitted by this manager.
+     *
+     * @param identifier Identifier to use for our subscription.
+     * @param serverSideMonitor Whether client supports server-side monitoring
+     * @return The path we got assigned. Contains identifier.
+     */
+    Q_SCRIPTABLE QDBusObjectPath subscribeV2( const QString &identifier, bool serverSideMonitor );
+
     /**
      * Unsubscribe from this manager.
      *
@@ -69,25 +81,36 @@ class NotificationManager : public QObject, protected QDBusContext
      */
     Q_SCRIPTABLE void unsubscribe( const QString &identifier );
 
+    /**
+     * Returns identifiers of currently subscribed sources
+     */
+    Q_SCRIPTABLE QStringList subscribers() const;
+
   Q_SIGNALS:
     Q_SCRIPTABLE void notify( const Akonadi::NotificationMessage::List &msgs );
 
+    Q_SCRIPTABLE void subscribed( const QString &identifier );
+    Q_SCRIPTABLE void unsubscribed( const QString &identifier );
+
   private Q_SLOTS:
     void slotNotify( const Akonadi::NotificationMessageV2::List &msgs );
 
   private:
-
     NotificationManager();
 
   private:
+    void registerSource( NotificationSource *source );
+    void unregisterSource( NotificationSource *source );
 
     static NotificationManager *mSelf;
     NotificationMessageV2::List mNotifications;
     QTimer mTimer;
 
-    //! One message source for each subscibed process
-    QHash<QString, NotificationSource*> mNotificationSources;
+    //! One message source for each subscribed process
+    QHash<QString, NotificationSource *> mNotificationSources;
 
+    friend class NotificationSource;
+    friend class ::NotificationManagerTest;
 };
 
 }
