@@ -23,20 +23,17 @@
 #include "../libs/notificationmessagev2_p.h"
 
 #include <QtCore/QObject>
+#include <QtCore/QVector>
 #include <QtDBus/QtDBus>
 
+#include "entities.h"
 
 namespace Akonadi {
 
 class NotificationManager;
 
-/**
- * @brief "short description"
- *
- * @since :RELEASE_VERSION:
- */
 class NotificationSource : public QObject
-    {
+{
     Q_OBJECT
     Q_CLASSINFO( "D-Bus Interface", "org.freedesktop.Akonadi.NotificationSource" )
 
@@ -81,43 +78,73 @@ class NotificationSource : public QObject
     QString identifier() const;
 
     /**
-     * Add another client service to watch for. Auto-unsubcription only happens if
-     * all watched client servies have been stopped.
+     * Add another client service to watch for. Auto-unsubscription only happens if
+     * all watched client services have been stopped.
      */
     void addClientServiceName( const QString &clientServiceName );
 
-    public Q_SLOTS:
+    void setServerSideMonitorEnabled( bool enabled );
+    bool isServerSideMonitorEnabled() const;
 
-      /**
-       * Unsubscribe from the message source.
-       *
-       * This will delete the message source and make the used dbus path unavailable.
-       */
-      Q_SCRIPTABLE void unsubscribe();
+    bool acceptsNotification( const NotificationMessageV2 &notification );
 
-    Q_SIGNALS:
+  public Q_SLOTS:
+    /**
+      * Unsubscribe from the message source.
+      *
+      * This will delete the message source and make the used dbus path unavailable.
+      */
+    Q_SCRIPTABLE void unsubscribe();
 
-      Q_SCRIPTABLE void notify( const Akonadi::NotificationMessage::List &msgs );
-      Q_SCRIPTABLE void notifyV2( const Akonadi::NotificationMessageV2::List &msgs );
+    Q_SCRIPTABLE void setMonitoredCollection( Entity::Id id, bool monitored );
+    Q_SCRIPTABLE QVector<Entity::Id> monitoredCollections() const;
+    Q_SCRIPTABLE void setMonitoredItem( Entity::Id id, bool monitored );
+    Q_SCRIPTABLE QVector<Entity::Id> monitoredItems() const;
+    Q_SCRIPTABLE void setMonitoredResource( const QByteArray &resource, bool monitored );
+    Q_SCRIPTABLE QVector<QByteArray> monitoredResources() const;
+    Q_SCRIPTABLE void setMonitoredMimeType( const QString &mimeType, bool monitored );
+    Q_SCRIPTABLE QStringList monitoredMimeTypes() const;
+    Q_SCRIPTABLE void setAllMonitored( bool allMonitored );
+    Q_SCRIPTABLE bool isAllMonitored() const;
+    Q_SCRIPTABLE void setIgnoredSession( const QByteArray &sessionId, bool ignored );
+    Q_SCRIPTABLE QVector<QByteArray> ignoredSessions() const;
 
-    private Q_SLOTS:
-      void serviceUnregistered( const QString &serviceName );
+  Q_SIGNALS:
 
-    private:
+    Q_SCRIPTABLE void notify( const Akonadi::NotificationMessage::List &msgs );
+    Q_SCRIPTABLE void notifyV2( const Akonadi::NotificationMessageV2::List &msgs );
 
-      Akonadi::NotificationManager *mManager;
-      QString mIdentifier;
-      QString mDBusIdentifier;
-      QDBusServiceWatcher* mClientWatcher;
+    Q_SCRIPTABLE void monitoredCollectionsChanged();
+    Q_SCRIPTABLE void monitoredItemsChanged();
+    Q_SCRIPTABLE void monitoredResourcesChanged();
+    Q_SCRIPTABLE void monitoredMimeTypesChanged();
+    Q_SCRIPTABLE void isAllMonitoredChanged();
+    Q_SCRIPTABLE void ignoredSessionsChanged();
 
-    }; // class NotificationSource
+  private Q_SLOTS:
+    void serviceUnregistered( const QString &serviceName );
 
+  private:
+    bool isCollectionMonitored( Entity::Id id ) const;
+    bool isMimeTypeMonitored( const QString &mimeType ) const;
+    bool isMoveDestinationResourceMonitored( const NotificationMessageV2 &msg ) const;
 
+  private:
+    Akonadi::NotificationManager *mManager;
+    QString mIdentifier;
+    QString mDBusIdentifier;
+    QDBusServiceWatcher *mClientWatcher;
 
+    bool mServerSideMonitorEnabled;
+    bool mAllMonitored;
+    QSet<Entity::Id> mMonitoredCollections;
+    QSet<Entity::Id> mMonitoredItems;
+    QSet<QString> mMonitoredMimeTypes;
+    QSet<QByteArray> mMonitoredResources;
+    QSet<QByteArray> mIgnoredSessions;
+
+}; // class NotificationSource
 
 } // namespace Akonadi
 
-
-
 #endif // #define AKONADI_NOTIFICATIONSOURCE_H
-
