@@ -68,14 +68,17 @@ bool DbConfigPostgresql::init( QSettings &settings )
 
 #ifdef POSTGRES_PATH
     const QString dir( QLatin1String( POSTGRES_PATH ) );
-    if( QDir( dir ).exists() )
+    if ( QDir( dir ).exists() ) {
       postgresSearchPath << QLatin1String( POSTGRES_PATH );
+    }
 #endif
     postgresSearchPath << QLatin1String( "/usr/sbin" )
                        << QLatin1String( "/usr/local/sbin" )
                        << QLatin1String( "/usr/lib/postgresql/8.4/bin" )
                        << QLatin1String( "/usr/lib/postgresql/9.0/bin" )
-                       << QLatin1String( "/usr/lib/postgresql/9.1/bin" );
+                       << QLatin1String( "/usr/lib/postgresql/9.1/bin" )
+                       << QLatin1String( "/usr/lib/postgresql/9.2/bin" )
+                       << QLatin1String( "/usr/lib/postgresql/9.3/bin" );
 
     defaultServerPath = XdgBaseDirs::findExecutableFile( QLatin1String( "pg_ctl" ), postgresSearchPath );
     defaultInitDbPath = XdgBaseDirs::findExecutableFile( QLatin1String( "initdb" ), postgresSearchPath );
@@ -92,8 +95,8 @@ bool DbConfigPostgresql::init( QSettings &settings )
   mUserName = settings.value( QLatin1String( "User" ) ).toString();
   mPassword = settings.value( QLatin1String( "Password" ) ).toString();
   mConnectionOptions = settings.value( QLatin1String( "Options" ), defaultOptions ).toString();
-  mServerPath = settings.value( QLatin1String("ServerPath"), defaultServerPath ).toString();
-  mInitDbPath = settings.value( QLatin1String("InitDbPath"), defaultInitDbPath ).toString();
+  mServerPath = settings.value( QLatin1String( "ServerPath" ), defaultServerPath ).toString();
+  mInitDbPath = settings.value( QLatin1String( "InitDbPath" ), defaultInitDbPath ).toString();
   mCleanServerShutdownCommand = settings.value( QLatin1String( "CleanServerShutdownCommand" ), defaultCleanShutdownCommand ).toString();
   settings.endGroup();
 
@@ -102,10 +105,12 @@ bool DbConfigPostgresql::init( QSettings &settings )
   settings.setValue( QLatin1String( "Name" ), mDatabaseName );
   settings.setValue( QLatin1String( "Host" ), mHostName );
   settings.setValue( QLatin1String( "Options" ), mConnectionOptions );
-  if ( !mServerPath.isEmpty() )
+  if ( !mServerPath.isEmpty() ) {
     settings.setValue( QLatin1String( "ServerPath" ), mServerPath );
-  if ( !mInitDbPath.isEmpty() )
+  }
+  if ( !mInitDbPath.isEmpty() ) {
     settings.setValue( QLatin1String( "InitDbPath" ), mInitDbPath );
+  }
   settings.setValue( QLatin1String( "StartServer" ), mInternalServer );
   settings.endGroup();
   settings.sync();
@@ -115,14 +120,18 @@ bool DbConfigPostgresql::init( QSettings &settings )
 
 void DbConfigPostgresql::apply( QSqlDatabase &database )
 {
-  if ( !mDatabaseName.isEmpty() )
+  if ( !mDatabaseName.isEmpty() ) {
     database.setDatabaseName( mDatabaseName );
-  if ( !mHostName.isEmpty() )
+  }
+  if ( !mHostName.isEmpty() ) {
     database.setHostName( mHostName );
-  if ( !mUserName.isEmpty() )
+  }
+  if ( !mUserName.isEmpty() ) {
     database.setUserName( mUserName );
-  if ( !mPassword.isEmpty() )
+  }
+  if ( !mPassword.isEmpty() ) {
     database.setPassword( mPassword );
+  }
 
   database.setConnectOptions( mConnectionOptions );
 
@@ -195,17 +204,19 @@ void DbConfigPostgresql::startInternalServer()
     QSqlDatabase db = QSqlDatabase::addDatabase( QLatin1String( "QPSQL" ), initCon );
     apply( db );
 
-    // use the dummy database that is always available
-    db.setDatabaseName( QLatin1String( "template1" ) );
+    // use the default database that is always available
+    db.setDatabaseName( QLatin1String( "postgres" ) );
 
-    if ( !db.isValid() )
+    if ( !db.isValid() ) {
       akFatal() << "Invalid database object during database server startup";
+    }
 
     bool opened = false;
     for ( int i = 0; i < 120; ++i ) {
       opened = db.open();
-      if ( opened )
+      if ( opened ) {
         break;
+      }
 
       if ( mDatabaseProcess->waitForFinished( 500 ) ) {
         akError() << "Database process exited unexpectedly during initial connection!";
@@ -243,14 +254,16 @@ void DbConfigPostgresql::startInternalServer()
 
 void DbConfigPostgresql::stopInternalServer()
 {
-  if ( !mDatabaseProcess )
+  if ( !mDatabaseProcess ) {
     return;
+  }
 
   // first, try the nicest approach
   if ( !mCleanServerShutdownCommand.isEmpty() ) {
     QProcess::execute( mCleanServerShutdownCommand );
-    if ( mDatabaseProcess->waitForFinished( 3000 ) )
+    if ( mDatabaseProcess->waitForFinished( 3000 ) ) {
       return;
+    }
   }
 
   // if pg_ctl couldn't terminate all the postgres processes, we have to kill the master one.
