@@ -23,6 +23,7 @@
 #include "querybuilder.h"
 #include "dbexception.h"
 #include "shared/akdebug.h"
+#include "schema.h"
 
 #include <QtCore/QDebug>
 #include <QtCore/QFile>
@@ -32,8 +33,6 @@
 #include <QtSql/QSqlField>
 #include <QtSql/QSqlRecord>
 #include <QtSql/QSqlQuery>
-#include <QtXml/QDomDocument>
-#include <QtXml/QDomElement>
 #include <QtSql/QSqlError>
 
 #include <boost/bind.hpp>
@@ -41,53 +40,32 @@
 
 using namespace Akonadi;
 
-DbInitializer::ColumnDescription::ColumnDescription()
-  : size( -1 ), allowNull( true ), isAutoIncrement( false ), isPrimaryKey( false ), isUnique( false ), onUpdate( Cascade ), onDelete( Cascade )
-{
-}
-
-DbInitializer::IndexDescription::IndexDescription()
-  : isUnique( false )
-{
-}
-
-DbInitializer::DataDescription::DataDescription()
-{
-}
-
-DbInitializer::TableDescription::TableDescription()
-{
-}
-
-int DbInitializer::TableDescription::primaryKeyColumnCount() const
-{
-  return std::count_if( columns.constBegin(), columns.constEnd(), boost::bind<bool>( &ColumnDescription::isPrimaryKey, _1 ) );
-}
-
-DbInitializer::RelationDescription::RelationDescription()
-{
-}
-
-DbInitializer::Ptr DbInitializer::createInstance(const QSqlDatabase& database, const QString& templateFile)
+DbInitializer::Ptr DbInitializer::createInstance( const QSqlDatabase &database, Schema *schema )
 {
+  DbInitializer::Ptr i;
   switch ( DbType::type( database ) ) {
-    case DbType::MySQL:
-      return boost::shared_ptr<DbInitializer>( new DbInitializerMySql( database, templateFile ) );
-    case DbType::Sqlite:
-      return boost::shared_ptr<DbInitializer>( new DbInitializerSqlite( database, templateFile ) );
-    case DbType::PostgreSQL:
-      return boost::shared_ptr<DbInitializer>( new DbInitializerPostgreSql( database, templateFile ) );
-    case DbType::Virtuoso:
-      return boost::shared_ptr<DbInitializer>( new DbInitializerVirtuoso( database, templateFile ) );
-    case DbType::Unknown:
-      break;
+  case DbType::MySQL:
+    i.reset( new DbInitializerMySql( database ) );
+    break;
+  case DbType::Sqlite:
+    i.reset( new DbInitializerSqlite( database ) );
+    break;
+  case DbType::PostgreSQL:
+    i.reset( new DbInitializerPostgreSql( database ) );
+    break;
+  case DbType::Virtuoso:
+    i.reset( new DbInitializerVirtuoso( database ) );
+    break;
+  case DbType::Unknown:
+    akFatal() << database.driverName() << "backend not supported";
+    break;
   }
-  akFatal() << database.driverName() << "backend  not supported";
-  return boost::shared_ptr<DbInitializer>();
+  i->mSchema = schema;
+  return i;
 }
 
-DbInitializer::DbInitializer( const QSqlDatabase &database, const QString &templateFile )
-  : mDatabase( database ), mTemplateFile( templateFile ), mTestInterface( 0 ), m_noForeignKeyContraints( false )
+DbInitializer::DbInitializer( const QSqlDatabase &database )
+  : mDatabase( database ), mTestInterface( 0 ), m_noForeignKeyContraints( false )
 {
   m_introspector = DbIntrospector::createInstance( mDatabase );
 }
@@ -101,42 +79,16 @@ bool DbInitializer::run()
   try {
     akDebug() << "DbInitializer::run()";
 
-    QFile file( mTemplateFile );
-    if ( !file.open( QIODevice::ReadOnly ) ) {
-      mErrorMsg = QString::fromLatin1( "Unable to open template file '%1'." ).arg( mTemplateFile );
-      return false;
-    }
-
-    QDomDocument document;
-
-    QString errorMsg;
-    int line, column;
-    if ( !document.setContent( &file, &errorMsg, &line, &column ) ) {
-      mErrorMsg = QString::fromLatin1( "Unable to parse template file '%1': %2 (%3:%4)." )
-                        .arg( mTemplateFile ).arg( errorMsg ).arg( line ).arg( column );
-      return false;
-    }
-
-    const QDomElement documentElement = document.documentElement();
-    if ( documentElement.tagName() != QLatin1String( "database" ) ) {
-      mErrorMsg = QString::fromLatin1( "Invalid format of template file '%1'." ).arg( mTemplateFile );
-      return false;
-    }
-
-    QDomElement tableElement = documentElement.firstChildElement();
-    while ( !tableElement.isNull() ) {
-      if ( tableElement.tagName() == QLatin1String( "table" ) ) {
-        if ( !checkTable( parseTableDescription( tableElement ) ) )
-          return false;
-      } else if ( tableElement.tagName() == QLatin1String( "relation" ) ) {
-        if ( !checkRelation( tableElement ) )
-          return false;
-      } else {
-        mErrorMsg = QString::fromLatin1( "Unknown tag, expected <table> and got <%1>." ).arg( tableElement.tagName() );
+    Q_FOREACH ( const TableDescription &table, mSchema->tables() ) {
+      if ( !checkTable( table ) ) {
         return false;
       }
+    }
 
-      tableElement = tableElement.nextSiblingElement();
+    Q_FOREACH ( const RelationDescription &relation, mSchema->relations() ) {
+      if ( !checkRelation( relation ) ) {
+        return false;
+      }
     }
 
     akDebug() << "DbInitializer::run() done";
@@ -147,96 +99,6 @@ bool DbInitializer::run()
   return false;
 }
 
-DbInitializer::ColumnDescription::ReferentialAction DbInitializer::parseReferentialAction(const QString& refAction)
-{
-  if ( refAction.isEmpty() || refAction.toLower() == QLatin1String( "cascade" ) )
-    return DbInitializer::ColumnDescription::Cascade;
-  if ( refAction.toLower() == QLatin1String( "restrict" ) )
-    return DbInitializer::ColumnDescription::Restrict;
-  if ( refAction.toLower() == QLatin1String( "setnull" ) )
-    return DbInitializer::ColumnDescription::SetNull;
-
-  Q_ASSERT( !"format error" );
-  return DbInitializer::ColumnDescription::Cascade;
-}
-
-DbInitializer::TableDescription DbInitializer::parseTableDescription( const QDomElement &tableElement ) const
-{
-  TableDescription tableDescription;
-
-  tableDescription.name = tableElement.attribute( QLatin1String( "name" ) ) + QLatin1String( "Table" );
-
-  QDomElement childElement = tableElement.firstChildElement();
-  while ( !childElement.isNull() ) {
-    if ( childElement.tagName() == QLatin1String( "column" ) ) {
-      ColumnDescription columnDescription;
-
-      columnDescription.name = childElement.attribute( QLatin1String( "name" ) );
-      columnDescription.type = childElement.attribute( QLatin1String( "type" ) );
-
-      if ( childElement.hasAttribute( QLatin1String("size") ) )
-        columnDescription.size = childElement.attribute( QLatin1String("size") ).toInt();
-
-      if ( childElement.hasAttribute( QLatin1String( "allowNull" ) ) )
-        columnDescription.allowNull = (childElement.attribute( QLatin1String( "allowNull" ) ) == QLatin1String( "true" ));
-
-      if ( childElement.hasAttribute( QLatin1String( "isAutoIncrement" ) ) )
-        columnDescription.isAutoIncrement = (childElement.attribute( QLatin1String( "isAutoIncrement" ) ) == QLatin1String( "true" ));
-
-      if ( childElement.hasAttribute( QLatin1String( "isPrimaryKey" ) ) )
-        columnDescription.isPrimaryKey = (childElement.attribute( QLatin1String( "isPrimaryKey" ) ) == QLatin1String( "true" ));
-
-      if ( childElement.hasAttribute( QLatin1String( "isUnique" ) ) )
-        columnDescription.isUnique = (childElement.attribute( QLatin1String( "isUnique" ) ) == QLatin1String( "true" ));
-
-      columnDescription.refTable = childElement.attribute( QLatin1String( "refTable" ) );
-      columnDescription.refColumn = childElement.attribute( QLatin1String( "refColumn" ) );
-      columnDescription.defaultValue = childElement.attribute( QLatin1String( "default" ) );
-
-      columnDescription.onUpdate = parseReferentialAction( childElement.attribute( QLatin1String( "onUpdate" ) ) );
-      columnDescription.onDelete = parseReferentialAction( childElement.attribute( QLatin1String( "onDelete") ) );
-
-      tableDescription.columns.append( columnDescription );
-    } else if ( childElement.tagName() == QLatin1String( "index" ) ) {
-      IndexDescription indexDescription;
-
-      indexDescription.name = childElement.attribute( QLatin1String( "name" ) );
-      indexDescription.columns = childElement.attribute( QLatin1String( "columns" ) ).split( QLatin1Char( ',' ), QString::SkipEmptyParts );
-      indexDescription.isUnique = (childElement.attribute( QLatin1String( "unique" ) ) == QLatin1String( "true" ));
-
-      tableDescription.indexes.append( indexDescription );
-    } else if ( childElement.tagName() == QLatin1String( "data" ) ) {
-      DataDescription dataDescription;
-
-      const QStringList columns = childElement.attribute( QLatin1String( "columns" ) ).split( QLatin1Char( ',' ), QString::SkipEmptyParts );
-      const QStringList values = childElement.attribute( QLatin1String( "values" ) ).split( QLatin1Char( ',' ), QString::SkipEmptyParts );
-      Q_ASSERT( columns.count() == values.count() );
-
-      for ( int i = 0; i < columns.count(); ++i )
-        dataDescription.data.insert( columns.at( i ), values.at( i ) );
-
-      tableDescription.data.append( dataDescription );
-    }
-
-    childElement = childElement.nextSiblingElement();
-  }
-
-  return tableDescription;
-}
-
-DbInitializer::RelationDescription DbInitializer::parseRelationDescription( const QDomElement &element ) const
-{
-  RelationDescription relationDescription;
-
-  relationDescription.firstTable = element.attribute( QLatin1String( "table1" ) );
-  relationDescription.firstColumn = element.attribute( QLatin1String( "column1" ) );
-
-  relationDescription.secondTable = element.attribute( QLatin1String( "table2" ) );
-  relationDescription.secondColumn = element.attribute( QLatin1String( "column2" ) );
-
-  return relationDescription;
-}
-
 bool DbInitializer::checkTable( const TableDescription &tableDescription )
 {
   akDebug() << "checking table " << tableDescription.name;
@@ -277,8 +139,9 @@ bool DbInitializer::checkTable( const TableDescription &tableDescription )
   }
 
   // Add initial data if table is empty
-  if ( tableDescription.data.isEmpty() )
+  if ( tableDescription.data.isEmpty() ) {
     return true;
+  }
   if ( m_introspector->isTableEmpty( tableDescription.name ) ) {
     Q_FOREACH ( const DataDescription &dataDescription, tableDescription.data ) {
       // Get the INSERT VALUES statement for the specific SQL dialect
@@ -291,7 +154,7 @@ bool DbInitializer::checkTable( const TableDescription &tableDescription )
   return true;
 }
 
-void DbInitializer::checkForeignKeys(const DbInitializer::TableDescription& tableDescription)
+void DbInitializer::checkForeignKeys( const TableDescription &tableDescription )
 {
   try {
     const QVector<DbIntrospector::ForeignKey> existingForeignKeys = m_introspector->foreignKeyConstraints( tableDescription.name );
@@ -308,10 +171,9 @@ void DbInitializer::checkForeignKeys(const DbInitializer::TableDescription& tabl
         if ( !existingForeignKey.column.isEmpty() ) {
           // there's a constraint on this column, check if it's the correct one
           if ( QString::compare( existingForeignKey.refTable, column.refTable + QLatin1Literal( "table" ), Qt::CaseInsensitive ) == 0
-            && QString::compare( existingForeignKey.refColumn, column.refColumn, Qt::CaseInsensitive ) == 0
-            && QString::compare( existingForeignKey.onUpdate, referentialActionToString( column.onUpdate ), Qt::CaseInsensitive ) == 0
-            && QString::compare( existingForeignKey.onDelete, referentialActionToString( column.onDelete ), Qt::CaseInsensitive ) == 0 )
-          {
+               && QString::compare( existingForeignKey.refColumn, column.refColumn, Qt::CaseInsensitive ) == 0
+               && QString::compare( existingForeignKey.onUpdate, referentialActionToString( column.onUpdate ), Qt::CaseInsensitive ) == 0
+               && QString::compare( existingForeignKey.onDelete, referentialActionToString( column.onDelete ), Qt::CaseInsensitive ) == 0 ) {
             continue; // all good
           }
 
@@ -350,11 +212,8 @@ void DbInitializer::checkForeignKeys(const DbInitializer::TableDescription& tabl
   }
 }
 
-
-bool DbInitializer::checkRelation( const QDomElement &element )
+bool DbInitializer::checkRelation( const RelationDescription &relationDescription )
 {
-  const RelationDescription relationDescription = parseRelationDescription( element );
-
   const QString relationTableName = relationDescription.firstTable +
                                     relationDescription.secondTable +
                                     QLatin1String( "Relation" );
@@ -392,29 +251,36 @@ bool DbInitializer::hasForeignKeyConstraints() const
   return !m_noForeignKeyContraints;
 }
 
-QString DbInitializer::sqlType(const QString & type, int size) const
+QString DbInitializer::sqlType( const QString &type, int size ) const
 {
-  Q_UNUSED(size);
-  if ( type == QLatin1String("int") )
-    return QLatin1String("INTEGER");
-  if ( type == QLatin1String("qint64") )
+  Q_UNUSED( size );
+  if ( type == QLatin1String( "int" ) ) {
+    return QLatin1String( "INTEGER" );
+  }
+  if ( type == QLatin1String( "qint64" ) ) {
     return QLatin1String( "BIGINT" );
-  if ( type == QLatin1String("QString") )
-    return QLatin1String("TEXT");
-  if (type == QLatin1String("QByteArray") )
-    return QLatin1String("LONGBLOB");
-  if ( type == QLatin1String("QDateTime") )
-    return QLatin1String("TIMESTAMP");
-  if ( type == QLatin1String( "bool" ) )
-    return QLatin1String("BOOL");
+  }
+  if ( type == QLatin1String( "QString" ) ) {
+    return QLatin1String( "TEXT" );
+  }
+  if ( type == QLatin1String( "QByteArray" ) ) {
+    return QLatin1String( "LONGBLOB" );
+  }
+  if ( type == QLatin1String( "QDateTime" ) ) {
+    return QLatin1String( "TIMESTAMP" );
+  }
+  if ( type == QLatin1String( "bool" ) ) {
+    return QLatin1String( "BOOL" );
+  }
   Q_ASSERT( false );
   return QString();
 }
 
 QString DbInitializer::sqlValue( const QString &type, const QString &value ) const
 {
-  if ( type == QLatin1String( "QDateTime" ) && value == QLatin1String( "QDateTime::currentDateTime()" ) )
+  if ( type == QLatin1String( "QDateTime" ) && value == QLatin1String( "QDateTime::currentDateTime()" ) ) {
     return QLatin1String( "CURRENT_TIMESTAMP" );
+  }
 
   return value;
 }
@@ -434,49 +300,53 @@ QString DbInitializer::buildCreateIndexStatement( const TableDescription &tableD
                             .arg( indexDescription.columns.join( QLatin1String( "," ) ) );
 }
 
-QString DbInitializer::buildAddForeignKeyConstraintStatement(const DbInitializer::TableDescription& table, const DbInitializer::ColumnDescription& column) const
+QString DbInitializer::buildAddForeignKeyConstraintStatement( const TableDescription &table, const ColumnDescription &column ) const
 {
   Q_UNUSED( table );
   Q_UNUSED( column );
   return QString();
 }
 
-QString DbInitializer::buildRemoveForeignKeyConstraintStatement(const DbIntrospector::ForeignKey& fk, const DbInitializer::TableDescription& table) const
+QString DbInitializer::buildRemoveForeignKeyConstraintStatement( const DbIntrospector::ForeignKey &fk, const TableDescription &table ) const
 {
   Q_UNUSED( fk );
   Q_UNUSED( table );
   return QString();
 }
 
-QString DbInitializer::buildReferentialAction(DbInitializer::ColumnDescription::ReferentialAction onUpdate, DbInitializer::ColumnDescription::ReferentialAction onDelete)
+QString DbInitializer::buildReferentialAction( ColumnDescription::ReferentialAction onUpdate, ColumnDescription::ReferentialAction onDelete )
 {
   return QLatin1Literal( "ON UPDATE " ) + referentialActionToString( onUpdate )
-       + QLatin1Literal( " ON DELETE ") + referentialActionToString( onDelete );
+       + QLatin1Literal( " ON DELETE " ) + referentialActionToString( onDelete );
 }
 
-QString DbInitializer::referentialActionToString(DbInitializer::ColumnDescription::ReferentialAction action)
+QString DbInitializer::referentialActionToString( ColumnDescription::ReferentialAction action )
 {
   switch ( action ) {
-    case ColumnDescription::Cascade: return QLatin1String( "CASCADE" );
-    case ColumnDescription::Restrict: return QLatin1String( "RESTRICT" );
-    case ColumnDescription::SetNull: return QLatin1String( "SET NULL" );
+  case ColumnDescription::Cascade:
+    return QLatin1String( "CASCADE" );
+  case ColumnDescription::Restrict:
+    return QLatin1String( "RESTRICT" );
+  case ColumnDescription::SetNull:
+    return QLatin1String( "SET NULL" );
   }
 
   Q_ASSERT( !"invalid referential action enum!" );
   return QString();
 }
 
-QString DbInitializer::buildPrimaryKeyStatement(const DbInitializer::TableDescription& table)
+QString DbInitializer::buildPrimaryKeyStatement( const TableDescription &table )
 {
   QStringList cols;
-  Q_FOREACH( const ColumnDescription &column, table.columns ) {
-    if ( column.isPrimaryKey )
+  Q_FOREACH ( const ColumnDescription &column, table.columns ) {
+    if ( column.isPrimaryKey ) {
       cols.push_back( column.name );
+    }
   }
   return QLatin1Literal( "PRIMARY KEY (" ) + cols.join( QLatin1String( ", " ) ) + QLatin1Char( ')' );
 }
 
-void DbInitializer::execQuery(const QString& queryString)
+void DbInitializer::execQuery( const QString &queryString )
 {
   // if ( Q_UNLIKELY( mTestInterface ) ) { Qt 4.7 has no Q_UNLIKELY yet
   if ( mTestInterface ) {
@@ -485,17 +355,17 @@ void DbInitializer::execQuery(const QString& queryString)
   }
 
   QSqlQuery query( mDatabase );
-  if ( !query.exec( queryString ) )
+  if ( !query.exec( queryString ) ) {
     throw DbException( query );
+  }
 }
 
-
 void DbInitializer::setTestInterface( TestInterface *interface )
 {
   mTestInterface = interface;
 }
 
-void DbInitializer::setIntrospector(const DbIntrospector::Ptr& introspector)
+void DbInitializer::setIntrospector( const DbIntrospector::Ptr &introspector )
 {
   m_introspector = introspector;
 }
