@@ -22,17 +22,18 @@
 
 //BEGIN MySQL
 
-DbInitializerMySql::DbInitializerMySql(const QSqlDatabase& database, const QString& templateFile):
-  DbInitializer(database, templateFile)
+DbInitializerMySql::DbInitializerMySql( const QSqlDatabase &database )
+  : DbInitializer( database )
 {
 }
 
-QString DbInitializerMySql::sqlType(const QString & type, int size) const
+QString DbInitializerMySql::sqlType( const QString &type, int size ) const
 {
-  if ( type == QLatin1String( "QString" ) )
-    return QLatin1Literal("VARBINARY(") + QString::number(size <= 0 ? 255 : size) + QLatin1Literal(")");
-  else
+  if ( type == QLatin1String( "QString" ) ) {
+    return QLatin1Literal( "VARBINARY(" ) + QString::number( size <= 0 ? 255 : size ) + QLatin1Literal( ")" );
+  } else {
     return DbInitializer::sqlType( type, size );
+  }
 }
 
 QString DbInitializerMySql::buildCreateTableStatement( const TableDescription &tableDescription ) const
@@ -52,8 +53,9 @@ QString DbInitializerMySql::buildCreateTableStatement( const TableDescription &t
     }
   }
 
-  if ( tableDescription.primaryKeyColumnCount() > 1 )
+  if ( tableDescription.primaryKeyColumnCount() > 1 ) {
     columns.push_back( buildPrimaryKeyStatement( tableDescription ) );
+  }
   columns << references;
 
   const QString tableProperties = QLatin1String( " COLLATE=utf8_general_ci DEFAULT CHARSET=utf8" );
@@ -67,23 +69,28 @@ QString DbInitializerMySql::buildColumnStatement( const ColumnDescription &colum
 
   column += QLatin1Char( ' ' ) + sqlType( columnDescription.type, columnDescription.size );
 
-  if ( !columnDescription.allowNull )
+  if ( !columnDescription.allowNull ) {
     column += QLatin1String( " NOT NULL" );
+  }
 
-  if ( columnDescription.isAutoIncrement )
+  if ( columnDescription.isAutoIncrement ) {
     column += QLatin1String( " AUTO_INCREMENT" );
+  }
 
-  if ( columnDescription.isPrimaryKey && tableDescription.primaryKeyColumnCount() == 1 )
+  if ( columnDescription.isPrimaryKey && tableDescription.primaryKeyColumnCount() == 1 ) {
     column += QLatin1String( " PRIMARY KEY" );
+  }
 
-  if ( columnDescription.isUnique )
+  if ( columnDescription.isUnique ) {
     column += QLatin1String( " UNIQUE" );
+  }
 
   if ( !columnDescription.defaultValue.isEmpty() ) {
     const QString defaultValue = sqlValue( columnDescription.type, columnDescription.defaultValue );
 
-    if ( !defaultValue.isEmpty() )
+    if ( !defaultValue.isEmpty() ) {
       column += QString::fromLatin1( " DEFAULT %1" ).arg( defaultValue );
+    }
   }
 
   return column;
@@ -95,7 +102,7 @@ QString DbInitializerMySql::buildInsertValuesStatement( const TableDescription &
   QMutableHashIterator<QString, QString> it( data );
   while ( it.hasNext() ) {
     it.next();
-    it.value().replace( QLatin1String("\\"), QLatin1String("\\\\") );
+    it.value().replace( QLatin1String( "\\" ), QLatin1String( "\\\\" ) );
   }
 
   return QString::fromLatin1( "INSERT INTO %1 (%2) VALUES (%3)" )
@@ -104,26 +111,24 @@ QString DbInitializerMySql::buildInsertValuesStatement( const TableDescription &
                             .arg( QStringList( data.values() ).join( QLatin1String( "," ) ) );
 }
 
-QString DbInitializerMySql::buildAddForeignKeyConstraintStatement(const DbInitializer::TableDescription& table, const DbInitializer::ColumnDescription& column) const
+QString DbInitializerMySql::buildAddForeignKeyConstraintStatement( const TableDescription &table, const ColumnDescription &column ) const
 {
   return QLatin1Literal( "ALTER TABLE " ) + table.name + QLatin1Literal( " ADD FOREIGN KEY (" ) + column.name
        + QLatin1Literal( ") REFERENCES " ) + column.refTable + QLatin1Literal( "Table(" ) + column.refColumn
        + QLatin1Literal( ") " ) + buildReferentialAction( column.onUpdate, column.onDelete );
 }
 
-QString DbInitializerMySql::buildRemoveForeignKeyConstraintStatement(const DbIntrospector::ForeignKey& fk, const DbInitializer::TableDescription& table) const
+QString DbInitializerMySql::buildRemoveForeignKeyConstraintStatement( const DbIntrospector::ForeignKey &fk, const TableDescription &table ) const
 {
   return QLatin1Literal( "ALTER TABLE " ) + table.name + QLatin1Literal( " DROP FOREIGN KEY " ) + fk.name;
 }
 
 //END MySQL
 
-
-
 //BEGIN Sqlite
 
-DbInitializerSqlite::DbInitializerSqlite(const QSqlDatabase& database, const QString& templateFile):
-  DbInitializer(database, templateFile)
+DbInitializerSqlite::DbInitializerSqlite( const QSqlDatabase &database )
+  : DbInitializer( database )
 {
 }
 
@@ -131,11 +136,13 @@ QString DbInitializerSqlite::buildCreateTableStatement( const TableDescription &
 {
   QStringList columns;
 
-  Q_FOREACH ( const ColumnDescription &columnDescription, tableDescription.columns )
+  Q_FOREACH ( const ColumnDescription &columnDescription, tableDescription.columns ) {
     columns.append( buildColumnStatement( columnDescription, tableDescription ) );
+  }
 
-  if ( tableDescription.primaryKeyColumnCount() > 1 )
+  if ( tableDescription.primaryKeyColumnCount() > 1 ) {
     columns.push_back( buildPrimaryKeyStatement( tableDescription ) );
+  }
 
   return QString::fromLatin1( "CREATE TABLE %1 (%2)" ).arg( tableDescription.name, columns.join( QLatin1String( ", " ) ) );
 }
@@ -144,27 +151,32 @@ QString DbInitializerSqlite::buildColumnStatement( const ColumnDescription &colu
 {
   QString column = columnDescription.name + QLatin1Char( ' ' );
 
-  if ( columnDescription.isAutoIncrement )
+  if ( columnDescription.isAutoIncrement ) {
     column += QLatin1String( "INTEGER" );
-  else
+  } else {
     column += sqlType( columnDescription.type, columnDescription.size );
+  }
 
-  if ( columnDescription.isPrimaryKey && tableDescription.primaryKeyColumnCount() == 1 )
+  if ( columnDescription.isPrimaryKey && tableDescription.primaryKeyColumnCount() == 1 ) {
     column += QLatin1String( " PRIMARY KEY" );
-  else if ( columnDescription.isUnique )
+  } else if ( columnDescription.isUnique ) {
     column += QLatin1String( " UNIQUE" );
+  }
 
-  if ( columnDescription.isAutoIncrement )
+  if ( columnDescription.isAutoIncrement ) {
     column += QLatin1String( " AUTOINCREMENT" );
+  }
 
-  if ( !columnDescription.allowNull )
+  if ( !columnDescription.allowNull ) {
     column += QLatin1String( " NOT NULL" );
+  }
 
   if ( !columnDescription.defaultValue.isEmpty() ) {
     const QString defaultValue = sqlValue( columnDescription.type, columnDescription.defaultValue );
 
-    if ( !defaultValue.isEmpty() )
+    if ( !defaultValue.isEmpty() ) {
       column += QString::fromLatin1( " DEFAULT %1" ).arg( defaultValue );
+    }
   }
 
   return column;
@@ -188,21 +200,22 @@ QString DbInitializerSqlite::buildInsertValuesStatement( const TableDescription
 
 //END Sqlite
 
-
-
 //BEGIN PostgreSQL
 
-DbInitializerPostgreSql::DbInitializerPostgreSql(const QSqlDatabase& database, const QString& templateFile):
-  DbInitializer(database, templateFile)
+DbInitializerPostgreSql::DbInitializerPostgreSql( const QSqlDatabase &database )
+  : DbInitializer( database )
 {
 }
 
-QString DbInitializerPostgreSql::sqlType(const QString& type, int size) const
+QString DbInitializerPostgreSql::sqlType( const QString &type, int size ) const
 {
-  if ( type == QLatin1String("qint64") )
+  if ( type == QLatin1String( "qint64" ) ) {
     return QLatin1String( "int8" );
-  if ( type == QLatin1String("QByteArray") )
-    return QLatin1String("BYTEA");
+  }
+  if ( type == QLatin1String( "QByteArray" ) ) {
+    return QLatin1String( "BYTEA" );
+  }
+
   return DbInitializer::sqlType( type, size );
 }
 
@@ -210,11 +223,13 @@ QString DbInitializerPostgreSql::buildCreateTableStatement( const TableDescripti
 {
   QStringList columns;
 
-  Q_FOREACH ( const ColumnDescription &columnDescription, tableDescription.columns )
+  Q_FOREACH ( const ColumnDescription &columnDescription, tableDescription.columns ) {
     columns.append( buildColumnStatement( columnDescription, tableDescription ) );
+  }
 
-  if ( tableDescription.primaryKeyColumnCount() > 1 )
+  if ( tableDescription.primaryKeyColumnCount() > 1 ) {
     columns.push_back( buildPrimaryKeyStatement( tableDescription ) );
+  }
 
   return QString::fromLatin1( "CREATE TABLE %1 (%2)" ).arg( tableDescription.name, columns.join( QLatin1String( ", " ) ) );
 }
@@ -223,18 +238,21 @@ QString DbInitializerPostgreSql::buildColumnStatement( const ColumnDescription &
 {
   QString column = columnDescription.name + QLatin1Char( ' ' );
 
-  if ( columnDescription.isAutoIncrement )
+  if ( columnDescription.isAutoIncrement ) {
     column += QLatin1String( "SERIAL" );
-  else
+  } else {
     column += sqlType( columnDescription.type, columnDescription.size );
+  }
 
-  if ( columnDescription.isPrimaryKey && tableDescription.primaryKeyColumnCount() == 1 )
+  if ( columnDescription.isPrimaryKey && tableDescription.primaryKeyColumnCount() == 1 ) {
     column += QLatin1String( " PRIMARY KEY" );
-  else if ( columnDescription.isUnique )
+  } else if ( columnDescription.isUnique ) {
     column += QLatin1String( " UNIQUE" );
+  }
 
-  if ( !columnDescription.allowNull && !( columnDescription.isPrimaryKey && tableDescription.primaryKeyColumnCount() == 1 ) )
+  if ( !columnDescription.allowNull && !( columnDescription.isPrimaryKey && tableDescription.primaryKeyColumnCount() == 1 ) ) {
     column += QLatin1String( " NOT NULL" );
+  }
 
   if ( !columnDescription.refTable.isEmpty() && !columnDescription.refColumn.isEmpty() ) {
     column += QString::fromLatin1( " REFERENCES %1Table(%2) " )
@@ -246,8 +264,9 @@ QString DbInitializerPostgreSql::buildColumnStatement( const ColumnDescription &
   if ( !columnDescription.defaultValue.isEmpty() ) {
     const QString defaultValue = sqlValue( columnDescription.type, columnDescription.defaultValue );
 
-    if ( !defaultValue.isEmpty() )
+    if ( !defaultValue.isEmpty() ) {
       column += QString::fromLatin1( " DEFAULT %1" ).arg( defaultValue );
+    }
   }
 
   return column;
@@ -265,31 +284,36 @@ QString DbInitializerPostgreSql::buildInsertValuesStatement( const TableDescript
 
 //END PostgreSQL
 
-
-
 //BEGIN Virtuoso
 
-DbInitializerVirtuoso::DbInitializerVirtuoso(const QSqlDatabase& database, const QString& templateFile):
-  DbInitializer(database, templateFile)
+DbInitializerVirtuoso::DbInitializerVirtuoso( const QSqlDatabase &database )
+  : DbInitializer( database )
 {
 }
 
-QString DbInitializerVirtuoso::sqlType(const QString& type, int size) const
+QString DbInitializerVirtuoso::sqlType( const QString &type, int size ) const
 {
-  if ( type == QLatin1String("QString") )
-    return QLatin1Literal("VARCHAR(") + QString::number(size <= 0 ? 255 : size) + QLatin1Literal(")");
-  if (type == QLatin1String("QByteArray") )
-    return QLatin1String("LONG VARCHAR");
-  if ( type == QLatin1String( "bool" ) )
-    return QLatin1String("CHAR");
+  if ( type == QLatin1String( "QString" ) ) {
+    return QLatin1Literal( "VARCHAR(" ) + QString::number( size <= 0 ? 255 : size ) + QLatin1Literal( ")" );
+  }
+  if ( type == QLatin1String( "QByteArray" )  ) {
+    return QLatin1String( "LONG VARCHAR" );
+  }
+  if ( type == QLatin1String( "bool" ) ) {
+    return QLatin1String( "CHAR" );
+  }
   return DbInitializer::sqlType( type, size );
 }
 
-QString DbInitializerVirtuoso::sqlValue(const QString& type, const QString& value) const
+QString DbInitializerVirtuoso::sqlValue( const QString &type, const QString &value ) const
 {
   if ( type == QLatin1String( "bool" ) ) {
-    if ( value == QLatin1String( "false" ) ) return QLatin1String( "0" );
-    if ( value == QLatin1String( "true" ) ) return QLatin1String( "1" );
+    if ( value == QLatin1String( "false" ) ) {
+      return QLatin1String( "0" );
+    }
+    if ( value == QLatin1String( "true" ) ) {
+      return QLatin1String( "1" );
+    }
   }
   return DbInitializer::sqlValue( type, value );
 }
@@ -298,11 +322,13 @@ QString DbInitializerVirtuoso::buildCreateTableStatement( const TableDescription
 {
   QStringList columns;
 
-  Q_FOREACH ( const ColumnDescription &columnDescription, tableDescription.columns )
+  Q_FOREACH ( const ColumnDescription &columnDescription, tableDescription.columns ) {
     columns.append( buildColumnStatement( columnDescription, tableDescription ) );
+  }
 
-  if ( tableDescription.primaryKeyColumnCount() > 1 )
+  if ( tableDescription.primaryKeyColumnCount() > 1 ) {
     columns.push_back( buildPrimaryKeyStatement( tableDescription ) );
+  }
 
   return QString::fromLatin1( "CREATE TABLE %1 (%2)" ).arg( tableDescription.name, columns.join( QLatin1String( ", " ) ) );
 }
@@ -313,17 +339,21 @@ QString DbInitializerVirtuoso::buildColumnStatement( const ColumnDescription &co
 
   column += QLatin1Char( ' ' ) + sqlType( columnDescription.type, columnDescription.size );
 
-  if ( !columnDescription.allowNull )
+  if ( !columnDescription.allowNull ) {
     column += QLatin1String( " NOT NULL" );
+  }
 
-  if ( columnDescription.isAutoIncrement )
+  if ( columnDescription.isAutoIncrement ) {
     column += QLatin1String( " IDENTITY" );
+  }
 
-  if ( columnDescription.isPrimaryKey && tableDescription.primaryKeyColumnCount() == 1 )
+  if ( columnDescription.isPrimaryKey && tableDescription.primaryKeyColumnCount() == 1 ) {
     column += QLatin1String( " PRIMARY KEY" );
+  }
 
-  if ( columnDescription.isUnique )
+  if ( columnDescription.isUnique ) {
     column += QLatin1String( " UNIQUE" );
+  }
 
   if ( !columnDescription.refTable.isEmpty() && !columnDescription.refColumn.isEmpty() ) {
     column += QLatin1Literal( " REFERENCES " ) + columnDescription.refTable + QLatin1Literal( "Table(" )
@@ -333,8 +363,9 @@ QString DbInitializerVirtuoso::buildColumnStatement( const ColumnDescription &co
   if ( !columnDescription.defaultValue.isEmpty() ) {
     const QString defaultValue = sqlValue( columnDescription.type, columnDescription.defaultValue );
 
-    if ( !defaultValue.isEmpty() && (defaultValue != QLatin1String( "CURRENT_TIMESTAMP" )) )
+    if ( !defaultValue.isEmpty() && ( defaultValue != QLatin1String( "CURRENT_TIMESTAMP" ) ) ) {
       column += QString::fromLatin1( " DEFAULT %1" ).arg( defaultValue );
+    }
   }
 
   return column;
