@@ -19,20 +19,24 @@
 
 #include "dbtype.h"
 
-DbType::Type DbType::type(const QSqlDatabase& db)
+DbType::Type DbType::type( const QSqlDatabase &db )
 {
   return typeForDriverName( db.driverName() );
 }
 
-DbType::Type DbType::typeForDriverName(const QString& driverName)
+DbType::Type DbType::typeForDriverName( const QString &driverName )
 {
-  if ( driverName.startsWith( QLatin1String( "QMYSQL" ) ) )
+  if ( driverName.startsWith( QLatin1String( "QMYSQL" ) ) ) {
     return MySQL;
-  if ( driverName == QLatin1String( "QPSQL" ) )
+  }
+  if ( driverName == QLatin1String( "QPSQL" ) ) {
     return PostgreSQL;
-  if ( driverName.startsWith( QLatin1String( "QSQLITE" ) ) )
+  }
+  if ( driverName.startsWith( QLatin1String( "QSQLITE" ) ) ) {
     return Sqlite;
-  if ( driverName.startsWith( QLatin1String( "QODBC" ) ) )
+  }
+  if ( driverName.startsWith( QLatin1String( "QODBC" ) ) ) {
     return Virtuoso;
+  }
   return Unknown;
 }
