@@ -24,14 +24,12 @@
 #include <qdbusabstractinterface.h>
 #include <qdebug.h>
 
-
 ItemRetrievalJob::~ItemRetrievalJob()
 {
   Q_ASSERT( !m_active );
 }
 
-
-void ItemRetrievalJob::start(QDBusAbstractInterface* interface)
+void ItemRetrievalJob::start( QDBusAbstractInterface *interface )
 {
   Q_ASSERT( m_request );
   akDebug() << "processing retrieval request for item" << m_request->id << " parts:" << m_request->parts << " of resource:" << m_request->resourceId;
@@ -59,36 +57,37 @@ void ItemRetrievalJob::kill()
   Q_EMIT requestCompleted( m_request, QLatin1String( "Request cancelled" ) );
 }
 
-void ItemRetrievalJob::callFinished(bool returnValue)
+void ItemRetrievalJob::callFinished( bool returnValue )
 {
   if ( m_active ) {
     m_active = false;
-    if ( !returnValue )
+    if ( !returnValue ) {
       Q_EMIT requestCompleted( m_request, QString::fromLatin1( "Resource was unable to deliver item" ) );
-    else
+    } else {
       Q_EMIT requestCompleted( m_request, QString() );
+    }
   }
   deleteLater();
 }
 
-void ItemRetrievalJob::callFinished(const QString& errorMsg)
+void ItemRetrievalJob::callFinished( const QString &errorMsg )
 {
   if ( m_active ) {
     m_active = false;
-    if ( !errorMsg.isEmpty() )
+    if ( !errorMsg.isEmpty() ) {
       Q_EMIT requestCompleted( m_request, QString::fromLatin1( "Unable to retrieve item from resource: %1" ).arg( errorMsg ) );
-    else
+    } else {
       Q_EMIT requestCompleted( m_request, QString() );
+    }
   }
   deleteLater();
 }
 
-
-void ItemRetrievalJob::callFailed(const QDBusError& error)
+void ItemRetrievalJob::callFailed( const QDBusError &error )
 {
   if ( error.type() == QDBusError::UnknownMethod && !m_oldMethodCalled ) {
     akDebug() << "processing retrieval request (old method) for item" << m_request->id << " parts:" << m_request->parts << " of resource:" << m_request->resourceId;
-    Q_ASSERT(m_interface);
+    Q_ASSERT( m_interface );
     //try the old version
     QList<QVariant> arguments;
     arguments << m_request->id
@@ -105,4 +104,3 @@ void ItemRetrievalJob::callFailed(const QDBusError& error)
   }
   deleteLater();
 }
-
