@@ -24,8 +24,8 @@
 
 using namespace Akonadi;
 
-ItemRetrievalThread::ItemRetrievalThread( QObject *parent ) :
-  QThread( parent )
+ItemRetrievalThread::ItemRetrievalThread( QObject *parent )
+  : QThread( parent )
 {
   // make sure we are created from the main thread, ie. before all other threads start to potentially use us
   Q_ASSERT( QThread::currentThread() == QCoreApplication::instance()->thread() );
@@ -37,4 +37,3 @@ void ItemRetrievalThread::run()
   exec();
   delete mgr;
 }
-
