@@ -29,6 +29,7 @@
 #include <QDir>
 #include <QFile>
 #include <QDebug>
+#include <QFileInfo>
 
 #include <QSqlError>
 
@@ -37,48 +38,60 @@ using namespace Akonadi;
 QString PartHelper::fileNameForPart( Part *part )
 {
   Q_ASSERT( part->id() >= 0 );
-  return storagePath() + QString::number( part->id() );
+  return QString::number( part->id() );
 }
 
 void PartHelper::update( Part *part, const QByteArray &data, qint64 dataSize )
 {
-  if (!part)
+  if ( !part ) {
     throw PartHelperException( "Invalid part" );
+  }
 
   QString origFileName;
+  QString origFilePath;
+
   // currently external, so recover the filename to delete it after the update succeeded
-  if ( part->external() )
+  if ( part->external() ) {
     origFileName = QString::fromUtf8( part->data() );
+    QFileInfo fi( origFileName );
+    if ( fi.isAbsolute() ) {
+      origFilePath = origFileName;
+      origFileName = fi.fileName();
+    } else if ( !origFileName.isEmpty() ) {
+      origFilePath = storagePath() + origFileName;
+    }
+  }
 
   const bool storeExternal = dataSize > DbConfig::configuredDatabase()->sizeThreshold();
 
   if ( storeExternal ) {
     QString fileName = origFileName;
-    if ( fileName.isEmpty() )
+    if ( fileName.isEmpty() ) {
       fileName = fileNameForPart( part );
-    QString rev = QString::fromAscii("_r0");
-    if ( fileName.contains( QString::fromAscii("_r") ) ) {
-      int revIndex = fileName.indexOf(QString::fromAscii("_r"));
-      rev = fileName.mid( revIndex + 2  );
+    }
+    QString rev = QString::fromAscii( "_r0" );
+    if ( fileName.contains( QString::fromAscii( "_r" ) ) ) {
+      int revIndex = fileName.indexOf( QString::fromAscii( "_r" ) );
+      rev = fileName.mid( revIndex + 2 );
       int r = rev.toInt();
       r++;
       rev = QString::number( r );
       fileName = fileName.left( revIndex );
-      rev.prepend( QString::fromAscii("_r") );
+      rev.prepend( QString::fromAscii( "_r" ) );
     }
     fileName += rev;
 
-    QFile file( fileName );
+    QFile file( storagePath() + fileName );
     if ( file.open( QIODevice::WriteOnly | QIODevice::Truncate ) ) {
       if ( file.write( data ) == data.size() ) {
         part->setData( fileName.toLocal8Bit() );
         part->setExternal( true );
       } else {
-        throw PartHelperException( QString::fromLatin1( "Failed to write into '%1', error was '%2'" ).arg( fileName ).arg( file.errorString() ) );
+        throw PartHelperException( QString::fromLatin1( "Failed to write into '%1', error was '%2'" ).arg( file.fileName() ).arg( file.errorString() ) );
       }
       file.close();
     } else  {
-     throw PartHelperException( QString::fromLatin1( "Could not open '%1' for writing, error was '%2'" ).arg( fileName ).arg( file.errorString() ) );
+     throw PartHelperException( QString::fromLatin1( "Could not open '%1' for writing, error was '%2'" ).arg( file.fileName() ).arg( file.errorString() ) );
     }
 
   // internal storage
@@ -89,17 +102,20 @@ void PartHelper::update( Part *part, const QByteArray &data, qint64 dataSize )
 
   part->setDatasize( dataSize );
   const bool result = part->update();
-  if ( !result )
+  if ( !result ) {
     throw PartHelperException( "Failed to update database record" );
+  }
   // everything worked, remove the old file
-  if ( !origFileName.isEmpty() )
-    removeFile( origFileName );
+  if ( !origFilePath.isEmpty() ) {
+    removeFile( origFilePath );
+  }
 }
 
-bool PartHelper::insert( Part *part, qint64* insertId )
+bool PartHelper::insert( Part *part, qint64 *insertId )
 {
-  if (!part)
+  if ( !part ) {
     return false;
+  }
 
   const bool storeInFile = part->datasize() > DbConfig::configuredDatabase()->sizeThreshold();
 
@@ -116,24 +132,24 @@ bool PartHelper::insert( Part *part, qint64* insertId )
 
   bool result = part->insert( insertId );
 
-  if ( storeInFile && result )
-  {
+  if ( storeInFile && result ) {
     QString fileName = fileNameForPart( part );
-    fileName +=  QString::fromUtf8("_r0");
+    fileName +=  QString::fromUtf8( "_r0" );
+    const QString filePath = storagePath() + QDir::separator() + fileName;
 
-    QFile file( fileName );
+    QFile file( filePath );
     if ( file.open( QIODevice::WriteOnly | QIODevice::Truncate ) ) {
       if ( file.write( data ) == data.size() ) {
         part->setData( fileName.toLocal8Bit() );
         result = part->update();
       } else {
-        akError() << "Insert: payload file " << fileName << " could not be written to!";
+        akError() << "Insert: payload file " << filePath << " could not be written to!";
         akError() << "Error: " << file.errorString();
         return false;
       }
       file.close();
     } else {
-      akError() << "Insert: payload file " << fileName << " could not be open for writing!";
+      akError() << "Insert: payload file " << filePath << " could not be open for writing!";
       akError() << "Error: " << file.errorString();
       return false;
     }
@@ -143,12 +159,13 @@ bool PartHelper::insert( Part *part, qint64* insertId )
 
 bool PartHelper::remove( Akonadi::Part *part )
 {
-  if (!part)
+  if ( !part ) {
     return false;
+  }
 
   if ( part->external() ) {
     // akDebug() << "remove part file " << part->data();
-    const QString fileName = QString::fromUtf8( part->data() );
+    const QString fileName = resolveAbsolutePath( part->data() );
     removeFile( fileName );
   }
   return part->remove();
@@ -168,26 +185,27 @@ bool PartHelper::remove( const QString &column, const QVariant &value )
   const Part::List parts = builder.result();
   Part::List::ConstIterator it = parts.constBegin();
   Part::List::ConstIterator end = parts.constEnd();
-  for ( ; it != end; ++it )
-  {
-    const QString fileName = QString::fromUtf8( (*it).data() );
+  for ( ; it != end; ++it ) {
+    const QString fileName = resolveAbsolutePath( ( *it ).data() );
     // akDebug() << "remove part file " << fileName;
     removeFile( fileName );
   }
   return Part::remove( column, value );
 }
 
-void PartHelper::removeFile(const QString& fileName)
+void PartHelper::removeFile( const QString &fileName )
 {
-  if ( !fileName.startsWith( storagePath() ) )
+  if ( !fileName.startsWith( storagePath() ) ) {
     throw PartHelperException( "Attempting to delete a file not in our prefix." );
+  }
   QFile::remove( fileName );
 }
 
 QByteArray PartHelper::translateData( const QByteArray &data, bool isExternal )
 {
   if ( isExternal ) {
-    const QString fileName = QString::fromUtf8( data );
+    const QString fileName = resolveAbsolutePath( data );
+
     QFile file( fileName );
     if ( file.open( QIODevice::ReadOnly ) ) {
       const QByteArray payload = file.readAll();
@@ -204,15 +222,15 @@ QByteArray PartHelper::translateData( const QByteArray &data, bool isExternal )
   }
 }
 
-QByteArray PartHelper::translateData( const Part& part )
+QByteArray PartHelper::translateData( const Part &part )
 {
   return translateData( part.data(), part.external() );
 }
 
-bool Akonadi::PartHelper::truncate(Part& part)
+bool Akonadi::PartHelper::truncate( Part &part )
 {
   if ( part.external() ) {
-    const QString fileName = QString::fromUtf8( part.data() );
+    const QString fileName = resolveAbsolutePath( part.data() );
     removeFile( fileName );
   }
 
@@ -229,10 +247,11 @@ QString PartHelper::storagePath()
   return dataDir;
 }
 
-bool PartHelper::verify(Part& part)
+bool PartHelper::verify( Part &part )
 {
-  const QString fileName = QString::fromUtf8( part.data() );
-  if ( !QFile::exists(fileName) ) {
+  const QString fileName = resolveAbsolutePath( part.data() );
+
+  if ( !QFile::exists( fileName ) ) {
     akError() << "Payload file" << fileName << "is missing, trying to recover.";
     part.setData( QByteArray() );
     part.setDatasize( 0 );
@@ -242,3 +261,14 @@ bool PartHelper::verify(Part& part)
 
   return true;
 }
+
+QString PartHelper::resolveAbsolutePath( const QByteArray &data )
+{
+    QString fileName = QString::fromUtf8( data );
+    QFileInfo fi( fileName );
+    if ( !fi.isAbsolute() ) {
+      fileName = storagePath() + fileName;
+    }
+
+    return fileName;
+}
